==> haskell-zlib-bindings-0.1.1.5-257-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zlib-bindings.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 zlib-bindings
version:              0.1.1.5
visibility:           public
id:                   zlib-bindings-0.1.1.5-AQntl26bnP8A9H0cD4xo1g
key:                  zlib-bindings-0.1.1.5-AQntl26bnP8A9H0cD4xo1g
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Experimental
homepage:             http://github.com/snoyberg/zlib-bindings
synopsis:             Low-level bindings to the zlib package. (deprecated)
description:          Deprecated in favor of streaming-commons
category:             Codec
abi:                  57110efc4a28e33dc9d3345d88aaaa2c
exposed:              True
exposed-modules:      Codec.Zlib Codec.Zlib.Lowlevel
import-dirs:          /usr/lib/ghc-9.6.6/site-local/zlib-bindings-0.1.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/zlib-bindings-0.1.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/zlib-bindings-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zlib-bindings
hs-libraries:         HSzlib-bindings-0.1.1.5-AQntl26bnP8A9H0cD4xo1g
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    zlib-0.7.0.0-3sNzZhB7apLBR7uUC6lcC

haddock-interfaces:
    /usr/share/doc/haskell-zlib-bindings/html/zlib-bindings.haddock

haddock-html:         /usr/share/doc/haskell-zlib-bindings/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zlib-bindings-0.1.1.5-258-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zlib-bindings.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 zlib-bindings
version:              0.1.1.5
visibility:           public
id:                   zlib-bindings-0.1.1.5-E4JOrLrVonA1PiGdrsSTJg
key:                  zlib-bindings-0.1.1.5-E4JOrLrVonA1PiGdrsSTJg
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Experimental
homepage:             http://github.com/snoyberg/zlib-bindings
synopsis:             Low-level bindings to the zlib package. (deprecated)
description:          Deprecated in favor of streaming-commons
category:             Codec
abi:                  428137f7312cc267c98f6acf5ac1414f
exposed:              True
exposed-modules:      Codec.Zlib Codec.Zlib.Lowlevel
import-dirs:          /usr/lib/ghc-9.6.6/site-local/zlib-bindings-0.1.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/zlib-bindings-0.1.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/zlib-bindings-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zlib-bindings
hs-libraries:         HSzlib-bindings-0.1.1.5-E4JOrLrVonA1PiGdrsSTJg
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    zlib-0.7.0.0-1ujaGtF2c5l6Jpv01tSCEr

haddock-interfaces:
    /usr/share/doc/haskell-zlib-bindings/html/zlib-bindings.haddock

haddock-html:         /usr/share/doc/haskell-zlib-bindings/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
